==> rescript-react-native-0.64.2.tgz: package/README.md <==
# `rescript-react-native`

[![Build Status](https://github.com/rescript-react-native/rescript-react-native/workflows/Build/badge.svg)](https://github.com/rescript-react-native/rescript-react-native/actions)
[![Version](https://img.shields.io/npm/v/rescript-react-native.svg)](https://www.npmjs.com/package/rescript-react-native)
[![ReScript Forum](https://img.shields.io/discourse/posts?color=e6484f&label=ReScript%20Forum&server=https%3A%2F%2Fforum.rescript-lang.org)](https://forum.rescript-lang.org/)

[ReScript](https://rescript-lang.org) bindings for
[React Native](https://github.com/facebook/react-native).

Allows to use ReScript with
[ReScript React](https://rescript-lang.org/docs/react/latest/introduction) to make your iOS,
Android and [Web](https://github.com/necolas/react-native-web) apps.

## Getting Started

Check our [getting started](https://rescript-react-native.github.io/en/docs/)
guide for details.

## Documentation

See <https://rescript-react-native.github.io/>.

---

## Changelog

Check the [changelog](./CHANGELOG.md) for more informations about recent
releases.

## Contribute

Read the [contribution guidelines](https://github.com/rescript-react-native/.github/blob/master/CONTRIBUTING.md) before contributing.

## Code of Conduct

We want this community to be friendly and respectful to each other. Please read
[our full code of conduct](https://github.com/rescript-react-native/.github/blob/master/CODE_OF_CONDUCT.md) so that you can understand what
actions will and will not be tolerated.

==> rescript-react-native-0.71.1.tgz: package/README.md <==
# `rescript-react-native`

[![Build Status](https://github.com/rescript-react-native/rescript-react-native/workflows/Build/badge.svg)](https://github.com/rescript-react-native/rescript-react-native/actions)
[![Version](https://img.shields.io/npm/v/rescript-react-native.svg)](https://www.npmjs.com/package/rescript-react-native)
[![ReScript Forum](https://img.shields.io/discourse/posts?color=e6484f&label=ReScript%20Forum&server=https%3A%2F%2Fforum.rescript-lang.org)](https://forum.rescript-lang.org/)

[ReScript](https://rescript-lang.org) bindings for
[React Native](https://github.com/facebook/react-native).

Allows to use ReScript with
[ReScript React](https://rescript-lang.org/docs/react/latest/introduction) to make your iOS,
Android and [Web](https://github.com/necolas/react-native-web) apps.

## Getting Started

Check our [getting started](https://rescript-react-native.github.io/docs/)
guide for details.

## Documentation

See <https://rescript-react-native.github.io/>.

---

## Changelog

Check the [changelog](./CHANGELOG.md) for more informations about recent
releases.

## Contribute

Read the [contribution guidelines](https://github.com/rescript-react-native/.github/blob/master/CONTRIBUTING.md) before contributing.

## Code of Conduct

We want this community to be friendly and respectful to each other. Please read
[our full code of conduct](https://github.com/rescript-react-native/.github/blob/master/CODE_OF_CONDUCT.md) so that you can understand what
actions will and will not be tolerated.
